@@ -2,6 +2,7 @@
 
 import os
 import re
+import time
 
 import sphinx
 
@@ -10,23 +11,25 @@ extensions = ['sphinx.ext.autodoc', 'sphinx.ext.doctest', 'sphinx.ext.todo',
               'sphinx.ext.intersphinx',
               'sphinx.ext.viewcode', 'sphinx.ext.inheritance_diagram']
 
-root_doc = 'contents'
 templates_path = ['_templates']
 exclude_patterns = ['_build']
 
 project = 'Sphinx'
-copyright = '2007-2022, Georg Brandl and the Sphinx team'
+copyright = f'2007-{time.strftime("%Y")}, the Sphinx developers'
 version = sphinx.__display_version__
 release = version
 show_authors = True
 
 html_theme = 'sphinx13'
 html_theme_path = ['_themes']
+html_css_files = [
+    # 'basic.css',  # included through inheritance from the basic theme
+    'sphinx13.css',
+]
 modindex_common_prefix = ['sphinx.']
 html_static_path = ['_static']
-html_sidebars = {'index': ['indexsidebar.html', 'searchbox.html']}
 html_title = 'Sphinx documentation'
-html_additional_pages = {'index': 'index.html'}
+html_additional_pages = {'contents': 'contents.html'}
 html_use_opensearch = 'https://www.sphinx-doc.org/en/master'
 html_baseurl = 'https://www.sphinx-doc.org/en/master/'
 html_favicon = '_static/favicon.svg'
@@ -35,7 +38,7 @@ htmlhelp_basename = 'Sphinxdoc'
 
 epub_theme = 'epub'
 epub_basename = 'sphinx'
-epub_author = 'Georg Brandl'
+epub_author = 'the Sphinx developers'
 epub_publisher = 'https://www.sphinx-doc.org/'
 epub_uid = 'web-site'
 epub_scheme = 'url'
@@ -45,6 +48,7 @@ epub_post_files = [('usage/installation.xhtml', 'Installing Sphinx'),
                    ('develop.xhtml', 'Sphinx development')]
 epub_exclude_files = ['_static/opensearch.xml', '_static/doctools.js',
                       '_static/jquery.js', '_static/searchtools.js',
+                      '_static/sphinx_highlight.js',
                       '_static/underscore.js', '_static/basic.css',
                       '_static/language_data.js',
                       'search.html', '_static/websupport.js']
@@ -52,11 +56,10 @@ epub_fix_images = False
 epub_max_image_width = 0
 epub_show_urls = 'inline'
 epub_use_index = False
-epub_guide = (('toc', 'contents.xhtml', 'Table of Contents'),)
 epub_description = 'Sphinx documentation generator system manual'
 
-latex_documents = [('contents', 'sphinx.tex', 'Sphinx Documentation',
-                    'Georg Brandl', 'manual', 1)]
+latex_documents = [('index', 'sphinx.tex', 'Sphinx Documentation',
+                    'the Sphinx developers', 'manual', 1)]
 latex_logo = '_static/sphinx.png'
 latex_elements = {
     'fontenc': r'\usepackage[LGR,X2,T1]{fontenc}',
@@ -74,6 +77,12 @@ latex_elements = {
              {\footnotesize\raggedright\printindex}
              {\begin{sphinxtheindex}\end{sphinxtheindex}}
 ''',
+    'sphinxsetup': """%
+VerbatimColor={RGB}{242,242,242},%
+VerbatimBorderColor={RGB}{32,32,32},%
+pre_border-radius=3pt,%
+pre_box-decoration-break=slice,%
+""",
 }
 latex_show_urls = 'footnote'
 latex_use_xindy = True
@@ -89,8 +98,8 @@ extlinks = {'duref': ('https://docutils.sourceforge.io/docs/ref/rst/'
                       'directives.html#%s', '%s')}
 
 man_pages = [
-    ('contents', 'sphinx-all', 'Sphinx documentation generator system manual',
-     'Georg Brandl', 1),
+    ('index', 'sphinx-all', 'Sphinx documentation generator system manual',
+     'the Sphinx developers', 1),
     ('man/sphinx-build', 'sphinx-build', 'Sphinx documentation generator tool',
      '', 1),
     ('man/sphinx-quickstart', 'sphinx-quickstart', 'Sphinx documentation '
@@ -102,7 +111,7 @@ man_pages = [
 ]
 
 texinfo_documents = [
-    ('contents', 'sphinx', 'Sphinx Documentation', 'Georg Brandl',
+    ('index', 'sphinx', 'Sphinx Documentation', 'the Sphinx developers',
      'Sphinx', 'The Sphinx documentation builder.', 'Documentation tools',
      1),
 ]
